# Overlapping Ranges

PyRanges objects can be subtracted from other PyRanges to report the intervals
in self that are not in other.

```{python tidy=FALSE}
import pyranges as pr
gr = pr.data.aorta()
gr2 = pr.data.aorta2()
print(gr.subtract(gr2))
```

Both methods also take a strandedness option, which can either be `"same"`, `"opposite"` or `False`/`None`

```{python tidy=FALSE}
print(gr.subtract(gr2, strandedness="opposite"))
```
